'------------------------------------------------------------------------------
' File:        homing.prg
' Purpose:     cartesian homing
' Version:     1.00
' Author:      Eran Korkidi
' Description: hard stop homing
' History:     15.MAR.2107 - Created
'------------------------------------------------------------------------------

dim shared dVelHoming as double = 5.0
dim shared daHomePos[4] as double
common shared gxHomeExecuted as long

program

	onerror
		catch 3017
			Sleep 1000
			Ctas homing.prg
		catch 65
			Sleep 1000
			Ctas homing.prg
		catch 3026
			? VesExecute("Sys.Motion = ON")
			Sleep 1000
			Ctas homing.prg
		catch 3253
			Sleep 1000
			Ctas homing.prg
	end onerror

	? VesExecute("Sys.Motion = ON")
	Sys.En = ON
	A1.En = OFF
	A2.En = OFF
	A3.En = OFF
	call HomeAxis(A1)
	call HomeAxis(A2)
	call HomeAxis(A3)
	call HomeMove
	gxHomeExecuted = TRUE
	
end program 

sub HomeMove

	Attach A1
	Attach A2
	Attach A3
		A1.En = ON
		A2.En = ON
		A3.En = ON
		sleep 1000
		Move A1 0 Vcruise=dVelHoming
		Move A2 0 Vcruise=dVelHoming
		Move A3 0 Vcruise=dVelHoming
		call waitMotion(A1)
		call waitMotion(A2)
		call waitMotion(A3)
	Detach A1
	Detach A2
	Detach A3

end sub

sub HomeAxis(Ax as generic axis)

	dim dPosition as double
	
	Attach Ax
	if Ax.Simulated then
		Ax.Disp = 0
		Ax.Disp = Ax.Pfb - 10
	else		
		Ax.Disp = 0
		Ax.En = 1
		Ax.PminEn = 0
		sleep 1000
		Move Ax -1000 Abs=0
		while Ax.IsMoving
			dPosition = Ax.Pfb
			Sleep 10
		end while
		Ax.Disp = dPosition - 10
		Ax.En = 0
		Ax.PeMax = 10
		Ax.PminEn = 1
	end if
	Detach Ax
	Print Ax.ElementName + ", Homing done"

end sub


sub waitMotion(Ax as generic axis)
	while Ax.IsMoving
		Sleep 1
	end while
end sub